##############################################################################
#
# Copyright (c) 2005-2009 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""BBB
"""

# BBB
from zope.browserpage.namedtemplate import INamedTemplate
from zope.browserpage.namedtemplate import NamedTemplate
from zope.browserpage.namedtemplate import NamedTemplateImplementation
from zope.browserpage.namedtemplate import NamedTemplatePathAdapter
from zope.browserpage.namedtemplate import implementation
